/**
 * @file
 * Lightship Theme Gulpfile for compiling Sass.
 */

// https://css-tricks.com/gulp-for-beginners/
const gulp = require('gulp');
// Converts Sass to CSS, using Dart sass compiler.
const sass = require('gulp-sass')(require('sass'));
// Create sass sourcemaps.
const sourcemaps = require('gulp-sourcemaps');
// Adds vendor prefixes to CSS rules.
const autoprefixer = require('gulp-autoprefixer');
// Delete generated files when needed.
const del = require('del');
// Used to catch errors and continue build
const plumber = require('gulp-plumber');

// Used to set whether CSS format is compressed or expanded when compiled.
let style = 'compressed';

// Compile sass to css.
gulp.task('sass', () => gulp.src('sass/**/*.scss')
  .pipe(plumber(function (error) {
    console.log(error.message);
    this.emit('end');
  }))
  .pipe(sourcemaps.init())
  .pipe(sass.sync({ outputStyle: style }))
  .pipe(autoprefixer())
  .pipe(sourcemaps.write('./'))
  .pipe(gulp.dest('css')));

// Clean up existing compiled files.
gulp.task('clean:css', (done) => {
  del.sync('css/*');
  done();
});

// Watch sass files & rebuild on any changes.
gulp.task('watch', () => {
  gulp.watch('sass/**/*.scss', gulp.series('sass'));
});

// One time build process.
gulp.task('build', (done) => {
  gulp.series('clean:css', 'sass')(done);
});

// One time build process, unminified CSS.
gulp.task('build:unminified', (done) =>{
  style = 'expanded';
  gulp.series('build')(done);
});

// Build sass & watch sass changes.
gulp.task('default', gulp.series('build', 'watch'));
